@@ -23,7 +23,7 @@ class SetupCog(commands.Cog):
         if platform.node().lower() == "secureerase":
             await asyncio.sleep(2)
 
-        if await context.message.fetch():
+        try:
             await context.message.delete()
             context.bot.tree.copy_global_to(guild=context.guild)
             synced = await context.bot.tree.sync(guild=context.guild)
@@ -31,9 +31,13 @@ class SetupCog(commands.Cog):
             role = discord.utils.get(self.client.guilds[0].roles, name="Dev")
             bot_member = discord.utils.get(self.client.get_all_members(), name="Doug Bot")
             if platform.node().lower() == "secureerase":
+                print("Switching to Prod")
                 await bot_member.remove_roles(role)
             else:
+                print("Switching to Dev")
                 await bot_member.add_roles(role)
+        except commands.errors.CommandInvokeError:
+            return
 
     @app_commands.command(name="clear")
     @app_commands.choices(
